=head1 NAME

MT::Plugins::SemWeb - MoveableType plugin to provides common semantic web markup

=cut

package MT::Plugins::SemWeb;

=head1 SYNOPSIS

Once installed in your MovableType plugins directory, the following
new tags will be available for use within templates:

<$MTRDFReferences$>

=head1 REQUIRES

 MovableType 2.6 or higher
 HTML::Parser

=head1 DESCRIPTION

=head2 MTRDFReferences

The <$MTRDFReferences$> tag provides XML/RDF markup for the
dcterms:references predicate for use in RSS 1.0 templates. See
L<http://web.resource.org/rss/1.0/modules/dcterms/#references>. 

All HTML anchors containing an href attribute are parsed from the
current entry's text, and returned as dcterms:references statements.
For example, given the HTML:

  I like <a href="http://www.megatokyo.com/">MegaTokyo</a>.

the <$MTRDFReferences$> will return this RDF:

  <dcterms:references xmlns:dcterms="http://purl.org/dc/terms/" rdf:resource="http://www.megatokyo.com/" />

=cut

use strict;
use warnings;

use MT 2.6;
use MT::Template::Context;
BEGIN {
	no warnings 'numeric';
	our $NAME		= "MTSemWeb";
	our $VERSION	= '0.001';
	our $plugin_data	= {
			name		=> "${NAME}, v${VERSION}",
			description => 'Provides template tags for common semantic web markup',
			doc_link	=> 'http://kasei.us/code/mtsemweb/'
		};
	
	if ($MT::VERSION >= 3.0) {
		require MT::Plugin;
		MT::Plugin->import();
		my $plugin	= new MT::Plugin($plugin_data);
		MT->add_plugin($plugin);
	}
}

use HTML::Parser;

our $debug		= 0;
use Data::Dumper;

######################################################################

MT::Template::Context->add_tag( RDFReferences => sub {
	my $warnings;
	local($SIG{__WARN__})	= sub { $warnings .= $_[0] };
	my $ctx		= shift;
	my $args	= shift;
	my $entry	= $ctx->stash('entry');
	my $html	= $entry->text;
	my @urls;
	my $parser	= HTML::Parser->new(
					api_version	=> 3,
					start_h		=> [
						sub {
							my ($tag, $attrs)	= @_;
							return unless $tag eq 'a';
							return unless exists($attrs->{'href'});
							push(@urls,$attrs->{'href'});
						},
						"tagname, attr"
					]
				);
	$parser->parse( $html );
	return join("\n\t", map {
			qq{<dcterms:references xmlns:dcterms="http://purl.org/dc/terms/" rdf:resource="${_}" />}
		} @urls);
} );

######################################################################

1;

__END__

=head1 SEE ALSO

 L<MT::Plugin>
 L<HTML::Parser>
 L<http://web.resource.org/rss/1.0/modules/dcterms/#references>

=head1 KNOWN BUGS

None.

=head1 TODO

None.

=head1 LICENSE

Copyright (c) 2004 Gregory Williams. All rights reserved. This program is free
software; you can redistribute it and/or modify it under the same terms as Perl
itself.

=head1 AUTHOR

 Gregory Williams <gwilliams@cpan.org>

=cut
